"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanRequest = scanRequest;
const scanUrl_1 = require("./scan/scanUrl");
const scanBody_1 = require("./scan/scanBody");
const scanHeaders_1 = require("./scan/scanHeaders");
const scanFormData_1 = require("./scan/scanFormData");
const scanCookies_1 = require("./scan/scanCookies");
const defaultOptions = {
    keys: true,
    values: true,
    detectSentences: true,
    detectReservedWords: true,
};
function scanRequest(url = '', body = {}, headers = {}, formData = new FormData(), cookies = {}, options = {
    checkUrl: defaultOptions,
    checkBody: defaultOptions,
    checkHeaders: defaultOptions,
    checkFormData: defaultOptions,
    checkCookies: defaultOptions,
}) {
    let issues = [];
    if (url !== '') {
        const checkUrl = Object.assign(Object.assign({}, defaultOptions), options.checkUrl);
        if (checkUrl.values) {
            issues = issues.concat((0, scanUrl_1.scanUrl)(url, checkUrl));
        }
    }
    if (Object.keys(body).length > 0) {
        const checkBody = Object.assign(Object.assign({}, defaultOptions), options.checkBody);
        issues = issues.concat((0, scanBody_1.scanBody)(body, checkBody));
    }
    if (Object.keys(headers).length > 0) {
        const checkHeaders = Object.assign(Object.assign({}, defaultOptions), options.checkHeaders);
        issues = issues.concat((0, scanHeaders_1.scanHeaders)(headers, checkHeaders));
    }
    if (formData.entries().next().done === false) {
        const checkFormData = Object.assign(Object.assign({}, defaultOptions), options.checkFormData);
        issues = issues.concat((0, scanFormData_1.scanFormData)(formData, checkFormData));
    }
    if (Object.keys(cookies).length > 0) {
        const checkCookies = Object.assign(Object.assign({}, defaultOptions), options.checkCookies);
        issues = issues.concat((0, scanCookies_1.scanCookies)(cookies, checkCookies));
    }
    return issues;
}
//# sourceMappingURL=index.js.map