"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanCookies = scanCookies;
const sqlInjectionDetector_1 = require("../detectors/sqlInjectionDetector");
const xssDetector_1 = require("../detectors/xssDetector");
const scriptInjectionDetector_1 = require("../detectors/scriptInjectionDetector");
function scanCookies(cookies, options) {
    const issues = [];
    const { detectSentences, detectReservedWords } = options;
    for (const [key, value] of Object.entries(cookies)) {
        if (detectSentences && (0, sqlInjectionDetector_1.isSQLSentence)(key)) {
            issues.push(`SQL Sentence detected in cookie key ${key}`);
        }
        if (detectReservedWords && (0, sqlInjectionDetector_1.detectSQLInjection)(key)) {
            issues.push(`SQL Injection detected in cookie key ${key}`);
        }
        if ((0, xssDetector_1.detectXSS)(key)) {
            issues.push(`XSS detected in cookie key ${key}`);
        }
        if ((0, scriptInjectionDetector_1.detectScriptInjection)(key)) {
            issues.push(`Script Injection detected in cookie key ${key}`);
        }
        if (detectSentences && (0, sqlInjectionDetector_1.isSQLSentence)(value)) {
            issues.push(`SQL Sentence detected in cookie value ${key}`);
        }
        if (detectReservedWords && (0, sqlInjectionDetector_1.detectSQLInjection)(value)) {
            issues.push(`SQL Injection detected in cookie value ${key}`);
        }
        if ((0, xssDetector_1.detectXSS)(value)) {
            issues.push(`XSS detected in cookie value ${key}`);
        }
        if ((0, scriptInjectionDetector_1.detectScriptInjection)(value)) {
            issues.push(`Script Injection detected in cookie value ${key}`);
        }
    }
    return issues;
}
//# sourceMappingURL=scanCookies.js.map