import { scanUrl } from './scan/scanUrl';
import { scanBody } from './scan/scanBody';
import { scanHeaders } from './scan/scanHeaders';
import { scanFormData } from './scan/scanFormData';
import { scanCookies } from './scan/scanCookies';

interface ScanOptions {
  checkUrl?: {
    keys?: boolean;
    values?: boolean;
    detectSentences?: boolean;
    detectReservedWords?: boolean;
  };
  checkBody?: {
    keys?: boolean;
    values?: boolean;
    detectSentences?: boolean;
    detectReservedWords?: boolean;
  };
  checkHeaders?: {
    keys?: boolean;
    values?: boolean;
    detectSentences?: boolean;
    detectReservedWords?: boolean;
  };
  checkFormData?: {
    keys?: boolean;
    values?: boolean;
    detectSentences?: boolean;
    detectReservedWords?: boolean;
  };
  checkCookies?: {
    keys?: boolean;
    values?: boolean;
    detectSentences?: boolean;
    detectReservedWords?: boolean;
  };
}

const defaultOptions = {
  keys: true,
  values: true,
  detectSentences: true,
  detectReservedWords: true,
};

export function scanRequest(
  url: string = '',
  body: any = {},
  headers: Record<string, string> = {},
  formData: FormData = new FormData(),
  cookies: Record<string, string> = {},
  options: ScanOptions = {
    checkUrl: defaultOptions,
    checkBody: defaultOptions,
    checkHeaders: defaultOptions,
    checkFormData: defaultOptions,
    checkCookies: defaultOptions,
  },
): string[] {
  let issues: string[] = [];

  if (url !== '') {
    const checkUrl = { ...defaultOptions, ...options.checkUrl };
    if (checkUrl.values) {
      issues = issues.concat(scanUrl(url, checkUrl));
    }
  }

  if (Object.keys(body).length > 0) {
    const checkBody = { ...defaultOptions, ...options.checkBody };
    issues = issues.concat(scanBody(body, checkBody));
  }

  if (Object.keys(headers).length > 0) {
    const checkHeaders = { ...defaultOptions, ...options.checkHeaders };
    issues = issues.concat(scanHeaders(headers, checkHeaders));
  }

  if (formData.entries().next().done === false) {
    const checkFormData = { ...defaultOptions, ...options.checkFormData };
    issues = issues.concat(scanFormData(formData, checkFormData));
  }

  if (Object.keys(cookies).length > 0) {
    const checkCookies = { ...defaultOptions, ...options.checkCookies };
    issues = issues.concat(scanCookies(cookies, checkCookies));
  }

  return issues;
}
