import {
  detectSQLInjection,
  isSQLSentence,
} from '../detectors/sqlInjectionDetector';
import { detectXSS } from '../detectors/xssDetector';
import { detectScriptInjection } from '../detectors/scriptInjectionDetector';

interface ScanOptions {
  detectSentences: boolean;
  detectReservedWords: boolean;
}

export function scanCookies(
  cookies: Record<string, string>,
  options: ScanOptions,
): string[] {
  const issues: string[] = [];

  const { detectSentences, detectReservedWords } = options;

  for (const [key, value] of Object.entries(cookies)) {
    if (detectSentences && isSQLSentence(key)) {
      issues.push(`SQL Sentence detected in cookie key ${key}`);
    }
    if (detectReservedWords && detectSQLInjection(key)) {
      issues.push(`SQL Injection detected in cookie key ${key}`);
    }
    if (detectXSS(key)) {
      issues.push(`XSS detected in cookie key ${key}`);
    }
    if (detectScriptInjection(key)) {
      issues.push(`Script Injection detected in cookie key ${key}`);
    }

    if (detectSentences && isSQLSentence(value)) {
      issues.push(`SQL Sentence detected in cookie value ${key}`);
    }
    if (detectReservedWords && detectSQLInjection(value)) {
      issues.push(`SQL Injection detected in cookie value ${key}`);
    }
    if (detectXSS(value)) {
      issues.push(`XSS detected in cookie value ${key}`);
    }
    if (detectScriptInjection(value)) {
      issues.push(`Script Injection detected in cookie value ${key}`);
    }
  }

  return issues;
}
