import {
  detectSQLInjection,
  isSQLSentence,
} from '../detectors/sqlInjectionDetector';
import { detectXSS } from '../detectors/xssDetector';
import { detectScriptInjection } from '../detectors/scriptInjectionDetector';

interface ScanOptions {
  keys: boolean;
  values: boolean;
  detectSentences: boolean;
  detectReservedWords: boolean;
}

export function scanHeaders(
  headers: Record<string, string>,
  options: ScanOptions,
): string[] {
  const issues: string[] = [];

  const { keys, values, detectSentences, detectReservedWords } = options;

  for (const [key, value] of Object.entries(headers)) {
    if (keys) {
      if (detectSentences && isSQLSentence(key)) {
        issues.push(`SQL Sentence detected in header key ${key}`);
      }
      if (detectReservedWords && detectSQLInjection(key)) {
        issues.push(`SQL Injection detected in header key ${key}`);
      }
      if (detectXSS(key)) {
        issues.push(`XSS detected in header key ${key}`);
      }
      if (detectScriptInjection(key)) {
        issues.push(`Script Injection detected in header key ${key}`);
      }
    }
    if (values) {
      if (detectSentences && isSQLSentence(value)) {
        issues.push(`SQL Sentence detected in header value ${key}`);
      }
      if (detectReservedWords && detectSQLInjection(value)) {
        issues.push(`SQL Injection detected in header value ${key}`);
      }
      if (detectXSS(value)) {
        issues.push(`XSS detected in header value ${key}`);
      }
      if (detectScriptInjection(value)) {
        issues.push(`Script Injection detected in header value ${key}`);
      }
    }
  }

  return issues;
}
